<?php

namespace Drupal\auditfiles\Batch;

use Drupal\auditfiles\Services\AuditFilesNotInDatabase;
use Drupal\Component\Utility\Html;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Process batch files.
 */
final class AuditFilesNotInDatabaseBatchProcess {

  /**
   * Class constructor.
   *
   * @param \Drupal\auditfiles\Services\AuditFilesNotInDatabase $notInDatabase
   *   Injected ServiceAuditFilesUsedNotManaged service.
   * @param string $fileName
   *   File name to process.
   */
  final protected function __construct(
    protected AuditFilesNotInDatabase $notInDatabase,
    protected string $fileName,
  ) {
  }

  /**
   * The batch process for adding the file.
   *
   * @param string $filename
   *   File name that to be process.
   * @param array $context
   *   Batch context.
   */
  public static function auditfilesNotInDatabaseBatchAddProcessBatch(string $filename, array &$context): void {
    (new static(
      static::getService(), $filename,
    ))->addDispatch($context);
  }

  /**
   * Adds filenames referenced in content in file_managed but not in file_usage.
   *
   * @param array $context
   *   Batch context.
   */
  protected function addDispatch(array &$context): void {
    $this->notInDatabase->auditfilesNotInDatabaseBatchAddProcessFile($this->fileName);
    $context['results'][] = Html::escape($this->fileName);
    $context['message'] = new TranslatableMarkup('Processed %filename.', ['%filename' => $this->fileName]);
  }

  /**
   * The batch process for deleting the file.
   *
   * @param string $filename
   *   File name that needs to be processed.
   * @param array $context
   *   Batch context.
   */
  public static function auditfilesNotInDatabaseBatchDeleteProcessBatch(string $filename, array &$context): void {
    (new static(
      static::getService(), $filename,
    ))->deleteDispatch($context);
  }

  /**
   * Deletes filenames referenced in content frm file_managed not in file_usage.
   *
   * @param array $context
   *   Batch context.
   */
  protected function deleteDispatch(array &$context): void {
    $this->notInDatabase->auditfilesNotInDatabaseBatchDeleteProcessFile($this->fileName);
    $context['results'][] = Html::escape($this->fileName);
    $context['message'] = new TranslatableMarkup('Processed %filename.', ['%filename' => $this->fileName]);
  }

  /**
   * Gets the related audit files service.
   */
  protected static function getService(): AuditFilesNotInDatabase {
    return \Drupal::service('auditfiles.not_in_database');
  }

}
