<?php

namespace Drupal\auditfiles\Batch;

use Drupal\auditfiles\Services\AuditFilesUsedNotReferenced;
use Drupal\Component\Utility\Html;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Process batch files.
 */
final class AuditFilesUsedNotReferencedBatchProcess {

  /**
   * Class constructor.
   *
   * @param \Drupal\auditfiles\Services\AuditFilesUsedNotReferenced $usedNotReferenced
   *   Injected ServiceAuditFilesUsedNotManaged service.
   * @param int $fileId
   *   File entity ID to delete.
   */
  final protected function __construct(
    protected AuditFilesUsedNotReferenced $usedNotReferenced,
    protected int $fileId,
  ) {
  }

  /**
   * The batch process for process the file ID(s).
   *
   * @param int $fileId
   *   File entity ID to delete.
   * @param array $context
   *   Batch context.
   */
  public static function auditfilesUsedNotReferencedBatchDeleteProcessBatch($fileId, array &$context): void {
    (new static(
      static::getService(), $fileId,
    ))->dispatch($context);
  }

  /**
   * Processes file removal from file_usage that are not referenced in content.
   *
   * @param array $context
   *   Batch context.
   */
  protected function dispatch(array &$context): void {
    $this->usedNotReferenced->auditfilesUsedNotReferencedBatchDeleteProcessFile($this->fileId);
    $context['results'][] = Html::escape($this->fileId);
    $context['message'] = new TranslatableMarkup('Processed file ID %file_id.', ['%file_id' => $this->fileId]);
  }

  /**
   * Gets the related audit files service.
   */
  protected static function getService(): AuditFilesUsedNotReferenced {
    return \Drupal::service('auditfiles.used_not_referenced');
  }

}
