<?php

namespace Drupal\auditfiles\Batch;

use Drupal\auditfiles\Services\AuditFilesManagedNotUsed;
use Drupal\Component\Utility\Html;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Batch Worker to handle Deleting entity records from file_managed table.
 */
final class AuditFilesManagedNotUsedBatchProcess {

  /**
   * Class constructor.
   *
   * @param \Drupal\auditfiles\Services\AuditFilesManagedNotUsed $managedNotUsed
   *   Injected ServiceAuditFilesManagedNotUsed service.
   * @param int $fileId
   *   File entity ID to delete.
   */
  final protected function __construct(
    protected AuditFilesManagedNotUsed $managedNotUsed,
    protected int $fileId,
  ) {
  }

  /**
   * Batch process to delete file entities from file_managed not in file_usage.
   *
   * @param int $fileId
   *   File entity ID to delete.
   * @param array $context
   *   Batch context.
   */
  public static function auditfilesManagedNotUsedBatchDeleteProcessBatch(int $fileId, array &$context): void {
    (new static(
      static::getService(),
      $fileId,
    ))->dispatch($context);
  }

  /**
   * Processes removal of files from file_managed that are not in file_usage.
   *
   * @param array $context
   *   Batch context.
   */
  protected function dispatch(array &$context): void {
    $this->managedNotUsed->auditfilesManagedNotUsedBatchDeleteProcessFile($this->fileId);
    $context['results'][] = Html::escape($this->fileId);
    $context['message'] = new TranslatableMarkup('Processed file ID %file_id.', ['%file_id' => $this->fileId]);
  }

  /**
   * Gets the related audit files service.
   */
  protected static function getService(): AuditFilesManagedNotUsed {
    return \Drupal::service('auditfiles.managed_not_used');
  }

}
